@@ -19,7 +19,7 @@
  * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  * 
- * $Id: Alibint.c,v 1.5 2000/12/13 04:22:37 jon Exp $
+ * $Id: Alibint.c 154 2006-07-15 23:24:18Z jon $
  * $NCDId: @(#)Alibint.c,v 1.28 1995/12/28 19:42:47 greg Exp $
  */
 
@@ -49,6 +49,11 @@ without express or implied warranty.
 
 #include "release.h"
 
+#if defined(__CYGWIN__)
+#include <asm/socket.h>
+#include <arpa/inet.h>
+#endif
+
 #include <audio/Alibint.h>
 #include <audio/Aos.h>
 #include "Alibnet.h"
@@ -57,6 +62,7 @@ without express or implied warranty.
 #ifdef SYSV	/* fd_set */
 #include <sys/socket.h>
 #endif
+#include <sys/time.h>
 #endif /* !WIN32 */
 
 /* check for both EAGAIN and EWOULDBLOCK, because some supposedly POSIX
@@ -112,29 +118,23 @@ typedef union {
 } _AuAlignedBuffer;
 
 static char *_AuAsyncReply (
-#if NeedFunctionPrototypes
-    AuServer *,		/* server */
-    auReply *,		/* rep */
-    char *,		/* buf */
-    int *, 		/* lenp */
-    AuBool		/* discard */
-#endif
+                            AuServer *,		/* server */
+                            auReply *,		/* rep */
+                            char *,		/* buf */
+                            int *, 		/* lenp */
+                            AuBool		/* discard */
 );
 
-static void _AuEnq(
-#if NeedFunctionPrototypes
-    AuServer *,			/* server */
-    auEvent *,			/* event */
-    int				/* who */
-#endif
+static void _AuEnq(AuServer *,	/* server */
+                   auEvent *,   /* event */
+                   int		/* who */
+
 );
 
 static void _AuEventEnqueued(
-#if NeedFunctionPrototypes
-    AuServer *,			/* server */
-    int,			/* who */
-    AuEvent *			/* event */
-#endif
+                             AuServer *,			/* server */
+                             int,			/* who */
+                             AuEvent *			/* event */
 );
 
 /*
@@ -155,6 +155,10 @@ static void _AuEventEnqueued(
  * the object they have created.
  */
 
+
+/* this is a mutex for _AuReadEvents() */
+static _AuMutex _rev_mutex = _AU_MUTEX_INITIALIZER;
+
 static int padlength[4] = {0, 3, 2, 1};
     /* lookup table for adding padding bytes to data that is read from
     	or written to the Au socket.  */
@@ -170,30 +174,30 @@ static auReq _dummy_request = {
  * until the connection is writable.
  */
 static void
-_AuWaitForWritable(aud)
-    AuServer *aud;
+_AuWaitForWritable(AuServer *aud)
 {
 #if !defined(AMOEBA) && !defined(_MINIX)
 #ifndef WIN32
-    AuInt32 r_mask[MSKCNT];
-    AuInt32 w_mask[MSKCNT];
+    fd_set r_mask;
+    fd_set w_mask;
     int nfound;
 
-    CLEARBITS(r_mask);
-    CLEARBITS(w_mask);
+    FD_ZERO(&r_mask);
+    FD_ZERO(&w_mask);
 
     while (1) {
-	BITSET(r_mask, aud->fd);
-        BITSET(w_mask, aud->fd);
+	FD_SET(aud->fd, &r_mask);
+        FD_SET(aud->fd, &w_mask);
 
 	do {
-	    nfound = select (aud->fd + 1, (fd_set *)r_mask, (fd_set *)w_mask,
+	    nfound = select (aud->fd + 1, &r_mask, &w_mask,
 			     (fd_set *)NULL, (struct timeval *)NULL);
 	    if (nfound < 0 && errno != EINTR)
 		_AuIOError(aud);
 	} while (nfound <= 0);
 
-	if (_AuANYSET(r_mask)) {
+	/* if (_AuANYSET(r_mask)) { */
+	if (FD_ISSET(aud->fd,&r_mask)) {
 #else /* WIN32 */
     fd_set rset, wset;
     int nfound;
@@ -256,7 +260,8 @@ _AuWaitForWritable(aud)
 	    } ENDITERATE
 	}
 #ifndef WIN32
-	if (_AuANYSET(w_mask))
+	/* if (_AuANYSET(w_mask))*/
+	if (FD_ISSET(aud->fd, &w_mask))
 	    return;
 #else /* WIN32 */
 	if (FD_ISSET(aud->fd, &wset))
@@ -272,18 +277,17 @@ _AuWaitForWritable(aud)
 
 
 static void
-_AuWaitForReadable(aud)
-  AuServer *aud;
+_AuWaitForReadable(AuServer *aud)
 {
 #ifndef WIN32
 #if !defined(AMOEBA) && !defined(_MINIX)
-    AuUint32 r_mask[MSKCNT];
+    fd_set r_mask;
     int result;
 	
-    CLEARBITS(r_mask);
+    FD_ZERO(&r_mask);
     do {
-	BITSET(r_mask, aud->fd);
-	result = select(aud->fd + 1, (fd_set *)r_mask,
+	FD_SET(aud->fd, &r_mask);
+	result = select(aud->fd + 1, &r_mask,
 			(fd_set *)NULL, (fd_set *)NULL, (struct timeval *)NULL);
 	if (result == -1 && errno != EINTR) _AuIOError(aud);
     } while (result <= 0);
@@ -316,8 +320,7 @@ _AuWaitForReadable(aud)
  * This routine may have to be reworked if int < AuInt32.
  */
 void
-_AuFlush (aud)
-	register AuServer *aud;
+_AuFlush (register AuServer *aud)
 {
 	register AuInt32 size, todo;
 	register int write_stat;
@@ -362,9 +365,7 @@ _AuFlush (aud)
 }
 
 int
-_AuEventsQueued (aud, mode)
-    register AuServer *aud;
-    int mode;
+_AuEventsQueued (register AuServer *aud, int mode)
 {
 	register int len;
 	int pend;
@@ -386,13 +387,13 @@ _AuEventsQueued (aud, mode)
 	 */
 	if (!pend && !aud->qlen && ++aud->conn_checker >= AUCONN_CHECK_FREQ)
 	{
-	    AuUint32 r_mask[MSKCNT];
+	    fd_set r_mask;
 	    static struct timeval zero_time;
 
 	    aud->conn_checker = 0;
-	    CLEARBITS(r_mask);
-	    BITSET(r_mask, aud->fd);
-	    if ((pend = select(aud->fd + 1, (fd_set *)r_mask, 
+	    FD_ZERO(&r_mask);
+	    FD_SET(aud->fd, &r_mask);
+	    if ((pend = select(aud->fd + 1, &r_mask, 
 		(fd_set *)NULL, (fd_set *)NULL,
 			      &zero_time)) != 0)
 	    {
@@ -449,60 +450,65 @@ _AuEventsQueued (aud, mode)
  * then read as many events as possible (but at least 1) and enqueue them
  */
 void
-_AuReadEvents(aud)
-	register AuServer *aud;
+_AuReadEvents(register AuServer *aud)
 {
-	_AuAlignedBuffer buf;
-	int pend;
-	register int len;
-	register auReply *rep;
-	AuBool not_yet_flushed = AuTrue;
+  _AuAlignedBuffer buf;
+  int pend;
+  register int len;
+  register auReply *rep;
+  AuBool not_yet_flushed = AuTrue;
+  
+  /* lock read access to the server */
+  _AuLockMutex(_rev_mutex);
 
-	do {
-	    /* find out how much data can be read */
-	    if (BytesReadable(aud->fd, (char *) &pend) < 0)
-	    	_AuIOError(aud);
-	    len = pend;
+  do {
+    /* find out how much data can be read */
+    if (BytesReadable(aud->fd, (char *) &pend) < 0)
+      _AuIOError(aud);
+    len = pend;
+    
+    /* must read at least one auEvent; if none is pending, then
+       we'll just flush and block waiting for it */
+    if (len < SIZEOF(auEvent)) {
+      len = SIZEOF(auEvent);
+      /* don't flush until we block the first time */
+      if (not_yet_flushed) {
+	int qlen = aud->qlen;
+	_AuFlush (aud);
+	if (qlen != aud->qlen) return;
+	not_yet_flushed = AuFalse;
+      }
+    }
+    
+    /* but we won't read more than the max buffer size */
+    if (len > BUFSIZE)
+      len = BUFSIZE;
+    
+    /* round down to an integral number of AuReps */
+    len = (len / SIZEOF(auEvent)) * SIZEOF(auEvent);
+    
+    _AuRead (aud, buf.buf, (AuInt32) len);
+    
+    STARTITERATE(rep,auReply,buf.buf,len > 0) {
+      if (rep->generic.type == Au_Reply) {
+	pend = len;
+	RESETITERPTR(rep,auReply,
+		     _AuAsyncReply (aud, rep,
+				    ITERPTR(rep), &pend, AuTrue));
+	len = pend;
+      } else {
+	if (rep->generic.type == Au_Error)
+	  _AuError (aud, (auError *) rep);
+	else   /* must be an event packet */
+	  _AuEnq (aud, (auEvent *)rep, AuEventEnqueuedByUnknown);
+	INCITERPTR(rep,auReply);
+	len -= SIZEOF(auReply);
+      }
+    } ENDITERATE
+  } while (aud->head == NULL);
 
-	    /* must read at least one auEvent; if none is pending, then
-	       we'll just flush and block waiting for it */
-	    if (len < SIZEOF(auEvent)) {
-	    	len = SIZEOF(auEvent);
-		/* don't flush until we block the first time */
-		if (not_yet_flushed) {
-		    int qlen = aud->qlen;
-		    _AuFlush (aud);
-		    if (qlen != aud->qlen) return;
-		    not_yet_flushed = AuFalse;
-		}
-	    }
-		
-	    /* but we won't read more than the max buffer size */
-	    if (len > BUFSIZE)
-	    	len = BUFSIZE;
+  _AuUnlockMutex(_rev_mutex);
 
-	    /* round down to an integral number of AuReps */
-	    len = (len / SIZEOF(auEvent)) * SIZEOF(auEvent);
-
-	    _AuRead (aud, buf.buf, (AuInt32) len);
-
-	    STARTITERATE(rep,auReply,buf.buf,len > 0) {
-		if (rep->generic.type == Au_Reply) {
-		    pend = len;
-		    RESETITERPTR(rep,auReply,
-				 _AuAsyncReply (aud, rep,
-					       ITERPTR(rep), &pend, AuTrue));
-		    len = pend;
-		} else {
-		    if (rep->generic.type == Au_Error)
-			_AuError (aud, (auError *) rep);
-		    else   /* must be an event packet */
-			_AuEnq (aud, (auEvent *)rep, AuEventEnqueuedByUnknown);
-		    INCITERPTR(rep,auReply);
-		    len -= SIZEOF(auReply);
-		}
-	    } ENDITERATE
-	} while (aud->head == NULL);
 }
 
 /* 
@@ -510,10 +516,7 @@ _AuReadEvents(aud)
  * reads.  This routine may have to be reworked if int < AuInt32.
  */
 void
-_AuRead (aud, data, size)
-	register AuServer *aud;
-	register char *data;
-	register AuInt32 size;
+_AuRead (register AuServer *aud, register char *data, register AuInt32 size)
 {
 	register AuInt32 bytes_read;
 
@@ -567,11 +570,8 @@ _AuRead (aud, data, size)
  *            into a AuInt32 (64 bits on a CRAY computer).
  * 
  */
-static _doXRead32 (aud, data, size, packbuffer)
-        register AuServer *aud;
-        register AuInt32 *data;
-        register AuInt32 size;
-	register char *packbuffer;
+static _doXRead32 (register AuServer *aud, register AuInt32 *data, 
+                   register AuInt32 size, register char *packbuffer)
 {
  AuInt32 *lpack,*lp;
  AuInt32 mask32 = 0x00000000ffffffff;
@@ -594,10 +594,7 @@ static _doXRead32 (aud, data, size, packbuffer)
         }
 }
 
-_AuRead32 (aud, data, len)
-    AuServer *aud;
-    AuInt32 *data;
-    AuInt32 len;
+_AuRead32 (AuServer *aud, AuInt32 *data, AuInt32 len)
 {
     char packbuffer[PACKBUFFERSIZE];
     unsigned nunits = PACKBUFFERSIZE >> 2;
@@ -615,7 +612,8 @@ _AuRead32 (aud, data, len)
  *            into a AuInt32 (64 bits on a CRAY computer).
  *
  */
-static _doXRead16 (aud, data, size, packbuffer)
+static _doXRead16 (register AuServer *aud, register short *data, 
+                   register AuInt32 size, char *packbuffer)
         register AuServer *aud;
         register short *data;
         register AuInt32 size;
@@ -642,10 +640,7 @@ static _doXRead16 (aud, data, size, packbuffer)
         }
 }
 
-_AuRead16 (aud, data, len)
-    AuServer *aud;
-    short *data;
-    AuInt32 len;
+_AuRead16 (AuServer *aud, short *data, AuInt32 len)
 {
     char packbuffer[PACKBUFFERSIZE];
     unsigned nunits = PACKBUFFERSIZE >> 1;
@@ -656,10 +651,7 @@ _AuRead16 (aud, data, len)
     if (len) _doXRead16 (aud, data, len, packbuffer);
 }
 
-_AuRead16Pad (aud, data, size)
-    AuServer *aud;
-    short *data;
-    AuInt32 size;
+_AuRead16Pad (AuServer *aud, short *data, AuInt32 size)
 {
     int slop = (size & 3);
     short slopbuf[3];
@@ -678,10 +670,7 @@ _AuRead16Pad (aud, data, size)
  * bytes. This routine may have to be reworked if int < AuInt32.
  */
 void
-_AuReadPad (aud, data, size)
-    	register AuServer *aud;	
-	register char *data;
-	register AuInt32 size;
+_AuReadPad (register AuServer *aud, register char *data, register AuInt32 size)
 {
     	register AuInt32 bytes_read;
 	struct iovec iov[2];
@@ -760,10 +749,7 @@ _AuReadPad (aud, data, size)
  * This routine may have to be reworked if int < AuInt32;
  */
 void
-_AuSend (aud, data, size)
-	register AuServer *aud;
-	char *data;
-	register AuInt32 size;
+_AuSend (register AuServer *aud, char *data, register AuInt32 size)
 {
 	struct iovec iov[3];
 	static char pad[3] = {0, 0, 0};
@@ -856,8 +842,7 @@ _AuSend (aud, data, size)
  * can roll his own and instatantiate it if he wants, but must
  * follow the rules.
  */
-AuID _AuAllocID (aud)
-    register AuServer *aud;
+AuID _AuAllocID (register AuServer *aud)
 {
    AuID id;
 
@@ -885,9 +870,7 @@ AuID _AuAllocID (aud)
  */
 
 AuUint32
-_AuSetLastRequestRead(aud, rep)
-    register AuServer *aud;
-    register auGenericReply *rep;
+_AuSetLastRequestRead(register AuServer *aud, register auGenericReply *rep)
 {
     register AuUint32	newseq, lastseq;
 
@@ -914,13 +897,12 @@ _AuSetLastRequestRead(aud, rep)
  * _AuReply - Wait for a reply packet and copy its contents into the
  * specified rep.  Mean while we must handle error and event packets that
  * we may encounter.
+ *
+ *   int extra;		number of 32-bit words expected after the reply 
+ *   AuBool discard;	should I discard data following "extra" words? 
  */
-AuBool _AuReply (aud, rep, extra, discard, ret_status)
-    register AuServer *aud;
-    register auReply *rep;
-    int extra;		/* number of 32-bit words expected after the reply */
-    AuBool discard;	/* should I discard data following "extra" words? */
-    AuStatus *ret_status;
+AuBool _AuReply (register AuServer *aud, register auReply *rep, 
+                 int extra, AuBool discard, AuStatus *ret_status)
 {
     /* Pull out the serial number now, so that (currently illegal) requests
      * generated by an error handler don't confuse us.
@@ -1041,12 +1023,8 @@ AuBool _AuReply (aud, rep, extra, discard, ret_status)
 }   
 
 static char *
-_AuAsyncReply(aud, rep, buf, lenp, discard)
-    AuServer *aud;
-    register auReply *rep;
-    char *buf;
-    register int *lenp;
-    AuBool discard;
+_AuAsyncReply(AuServer *aud, register auReply *rep, char *buf, 
+              register int *lenp, AuBool discard)
 {
     register _AuAsyncHandler *async, *next;
     register int len;
@@ -1102,12 +1080,8 @@ _AuAsyncReply(aud, rep, buf, lenp, discard)
  * error_code, major, and minor all to 0 to catch all errors.
  */
 AuBool
-_AuForceRoundTrip (aud, error_code, majorop, minorop, ret_status)
-    AuServer *aud;
-    int error_code;
-    int majorop;
-    int minorop;
-    AuStatus *ret_status;
+_AuForceRoundTrip (AuServer *aud, int error_code, int majorop, int minorop, 
+                   AuStatus *ret_status)
 {
     AuUint32 seq = aud->request;	 /* get previous request */
     auGetCloseDownModeReply rep;
@@ -1143,9 +1117,7 @@ _AuForceRoundTrip (aud, error_code, majorop, minorop, ret_status)
 
 /* Read and discard "n" 8-bit bytes of data */
 
-void _AuEatData (aud, n)
-    AuServer *aud;
-    register AuUint32 n;
+void _AuEatData (AuServer *aud, register AuUint32 n)
 {
 #define SCRATCHSIZE 2048
     char buf[SCRATCHSIZE];
@@ -1159,11 +1131,9 @@ void _AuEatData (aud, n)
 }
 
 AuEventEnqHandlerRec *
-AuRegisterEventEnqHandler(aud, who, callback, data)
-AuServer       *aud;
-int             who;
-AuEventEnqHandlerCallback callback;
-AuPointer       data;
+AuRegisterEventEnqHandler(AuServer *aud, int who, 
+                          AuEventEnqHandlerCallback callback, 
+                          AuPointer data)
 {
     AuEventEnqHandlerRec *handler;
 
@@ -1181,19 +1151,14 @@ AuPointer       data;
 }
 
 void
-AuUnregisterEventEnqHandler(aud, handler)
-AuServer       *aud;
-AuEventEnqHandlerRec *handler;
+AuUnregisterEventEnqHandler(AuServer *aud, AuEventEnqHandlerRec *handler)
 {
     _AuRemoveFromLinkedList(aud->eventenqhandlerq, handler);
     Aufree(handler);
 }
 
 static void
-_AuEventEnqueued(aud, who, event)
-AuServer       *aud;
-int             who;
-AuEvent        *event;
+_AuEventEnqueued(AuServer *aud, int who, AuEvent *event)
 {
     AuEventEnqHandlerRec *p = aud->eventenqhandlerq,
                    *next;
@@ -1211,10 +1176,7 @@ AuEvent        *event;
  * _AuEnq - Place event packets on the server's queue.
  */
 static void
-_AuEnq (aud, event, who)
-	register AuServer *aud;
-	register auEvent *event;
-        int who;
+_AuEnq (register AuServer *aud, register auEvent *event, int who)
 {
 	register _AuQEvent *qelt;
 
@@ -1246,14 +1208,16 @@ _AuEnq (aud, event, who)
 }
 /*
  * EventToWire in separate file in that often not needed.
+ *
+ * AuServer *aud;	 pointer to server structure 
+ * AuEvent *re;	         pointer to where event should be reformatted 
+ * auEvent *event;	 wire protocol event 
  */
 
 /*ARGSUSED*/
 AuBool
-_AuUnknownWireEvent(aud, re, event)
-register AuServer *aud;	/* pointer to server structure */
-register AuEvent *re;	/* pointer to where event should be reformatted */
-register auEvent *event;	/* wire protocol event */
+_AuUnknownWireEvent(register AuServer *aud, register AuEvent *re, 
+                    register auEvent *event)
 {
 #ifdef notdef
 	(void) fprintf(stderr, 
@@ -1265,10 +1229,8 @@ register auEvent *event;	/* wire protocol event */
 
 /*ARGSUSED*/
 AuStatus
-_AuUnknownNativeEvent(aud, re, event)
-register AuServer *aud;	/* pointer to server structure */
-register AuEvent *re;	/* pointer to where event should be reformatted */
-register auEvent *event;	/* wire protocol event */
+_AuUnknownNativeEvent(register AuServer *aud, register AuEvent *re, 
+                      register auEvent *event)
 {
 #ifdef notdef
 	(void) fprintf(stderr, 
@@ -1281,12 +1243,8 @@ register auEvent *event;	/* wire protocol event */
  * reformat a wire event into an AuEvent structure of the right type.
  */
 AuBool
-_AuWireToEvent(aud, re, event)
-register AuServer *aud;				/* pointer to server
-						 * structure */
-register AuEvent *re;				/* pointer to where event
-						 * should be reformatted */
-register auEvent *event;			/* wire protocol event */
+_AuWireToEvent(register AuServer *aud, register AuEvent *re, 
+               register auEvent *event)
 {
 
     re->type = event->u.u.type & 0x7f;
@@ -1344,16 +1302,9 @@ register auEvent *event;			/* wire protocol event */
 
 #ifndef USL_SHARELIB
 
-static char *_SysErrorMsg (n)
-    int n;
+static char *_SysErrorMsg (int n)
 {
-#if !defined(__FreeBSD__) && !defined(__linux__) && !defined(__NetBSD__)
-    extern char *sys_errlist[];
-#endif
-    extern int sys_nerr;
-    char *s = (char *)((n >= 0 && n < sys_nerr) ? sys_errlist[n] : "unknown error");
-
-    return (s ? s : "no such error");
+  return (strerror(n));
 }
 
 #endif 	/* USL sharedlibs in don't define for AUD3.2 */
@@ -1364,8 +1315,7 @@ static char *_SysErrorMsg (n)
  * when an Au internal system error is encountered.
  */
 void
-_AuDefaultIOError (aud)
-	AuServer *aud;
+_AuDefaultIOError (AuServer *aud)
 {
 	if (errno == EPIPE) {
 	    (void) fprintf (stderr,
@@ -1381,19 +1331,17 @@ _AuDefaultIOError (aud)
 			AuServerQLength(aud));
 
 	}
-	exit(1);
+	exit(1);                /* JET - is there a way to handle this
+                                   w/o being so heavy-handed? */
 }
 
 
-int _AuPrintDefaultError (aud, event, fp)
-    AuServer *aud;
-    AuErrorEvent *event;
-    FILE *fp;
+int _AuPrintDefaultError (AuServer *aud, AuErrorEvent *event, FILE *fp)
 {
     char buffer[BUFSIZ];
     char mesg[BUFSIZ];
     char number[32];
-    char *mtype = "audiolib";
+    const char *mtype = "audiolib";
     register _AuExtension *ext = (_AuExtension *)NULL;
     _AuExtension *bext = (_AuExtension *)NULL;
     AuGetErrorText(aud, event->error_code, buffer, BUFSIZ);
@@ -1475,9 +1423,7 @@ int _AuPrintDefaultError (aud, event, fp)
     return 1;
 }
 
-int _AuDefaultError(aud, event)
-	AuServer *aud;
-	AuErrorEvent *event;
+int _AuDefaultError(AuServer *aud, AuErrorEvent *event)
 {
     if (_AuPrintDefaultError (aud, event, stderr) == 0) return 0;
     exit(1);
@@ -1485,10 +1431,8 @@ int _AuDefaultError(aud, event)
 }
 
 /*ARGSUSED*/
-AuBool _AuDefaultWireError(server, he, we)
-    AuServer     *server;
-    AuErrorEvent *he;
-    auError      *we;
+AuBool _AuDefaultWireError(AuServer *server, AuErrorEvent *he, 
+                           auError *we)
 {
     return AuTrue;
 }
@@ -1496,9 +1440,7 @@ AuBool _AuDefaultWireError(server, he, we)
 /*
  * _AuError - upcall internal or user protocol error handler
  */
-int _AuError (aud, rep)
-    AuServer *aud;
-    register auError *rep;
+int _AuError (AuServer *aud, register auError *rep)
 {
     /* 
      * Au_Error packet encountered!  We need to unpack the error before
@@ -1544,8 +1486,7 @@ int _AuError (aud, rep)
 /*
  * _AuIOError - call user connection error handler and exit
  */
-int _AuIOError (aud)
-    AuServer *aud;
+int _AuIOError (AuServer *aud)
 {
     aud->flags |= AuServerFlagsIOError;
     if (aud->funcs.ioerror_handler != NULL)
@@ -1561,31 +1502,27 @@ int _AuIOError (aud)
  * audiolib routine for scratch space.  It is reallocated from the same place
  * each time, unless the library needs a large scratch space.
  */
-char *_AuAllocScratch (aud, nbytes)
-	register AuServer *aud;
-	AuUint32 nbytes;
+char *_AuAllocScratch (register AuServer *aud, AuUint32 nbytes)
 {
 	if (nbytes > aud->scratch_length) {
-	    if (aud->scratch_buffer) Aufree (aud->scratch_buffer);
-	    if ((aud->scratch_buffer = Aumalloc((unsigned) nbytes)) != NULL)
-		aud->scratch_length = nbytes;
+	    if (aud->scratch_buffer) Aufree ((void *)aud->scratch_buffer);
+	    if ((aud->scratch_buffer = 
+                 (char *)Aumalloc((unsigned) nbytes)) != NULL)
+              aud->scratch_length = nbytes;
 	    else aud->scratch_length = 0;
 	}
-	return (aud->scratch_buffer);
+	return ((char *)aud->scratch_buffer);
 }
 
 
 void 
-AuFree (data)
-    AuPointer data;
+AuFree (AuPointer data)
 {
 	Aufree (data);
 }
 
 #ifdef _AUNEEDBCOPYFUNC
-void _Aubcopy(b1, b2, length)
-    register char *b1, *b2;
-    register length;
+void _Aubcopy(register char *b1, register char *b2, register int length)
 {
     if (b1 < b2) {
 	b2 += length;
@@ -1600,10 +1537,7 @@ void _Aubcopy(b1, b2, length)
 #endif
 
 #ifdef _AuDataRoutineIsProcedure
-void _AuData (aud, data, len)
-	AuServer *aud;
-	char *data;
-	AuInt32 len;
+void _AuData (AuServer *aud, char *data, AuInt32 len)
 {
 	if (aud->bufptr + (len) <= aud->bufmax) {
 		bcopy(data, aud->bufptr, (int)len);
@@ -1630,11 +1564,8 @@ void _AuData (aud, data, len)
  * "len" is the length in bytes of the data.
  */
 
-static do_AuData16(aud, data, len, packbuffer)
-    register AuServer *aud;
-    short *data;
-    unsigned len;
-    char *packbuffer;
+static do_AuData16(register AuServer *aud, short *data, unsigned int len, 
+                   char *packbuffer)
 {
     AuInt32 *lp,*lpack;
     AuInt32 i, nwords,bits;
@@ -1663,10 +1594,7 @@ static do_AuData16(aud, data, len, packbuffer)
         _AuData(aud, packbuffer, len);
 }
 
-_AuData16 (aud, data, len)
-    AuServer *aud;
-    short *data;
-    unsigned len;
+_AuData16 (AuServer *aud, short *data, unsigned int len)
 {
     char packbuffer[PACKBUFFERSIZE];
     unsigned nunits = PACKBUFFERSIZE >> 1;
@@ -1685,11 +1613,8 @@ _AuData16 (aud, data, len)
  * "len" is the length in bytes of the data.
  */
 
-static do_AuData32 (aud, data, len, packbuffer)
-    register AuServer *aud;
-    AuInt32 *data;
-    unsigned len;
-    char *packbuffer;
+static do_AuData32 (register AuServer *aud, AuInt32 *data, 
+                    unsigned int len, char *packbuffer)
 {
     AuInt32 *lp,*lpack;
     AuInt32 i,bits,nwords;
@@ -1716,10 +1641,7 @@ static do_AuData32 (aud, data, len, packbuffer)
         _AuData(aud, packbuffer, len);
 }
 
-_AuData32 (aud, data, len)
-    AuServer *aud;
-    AuInt32 *data;
-    unsigned len;
+_AuData32 (AuServer *aud, AuInt32 *data, unsigned int len)
 {
     char packbuffer[PACKBUFFERSIZE];
     unsigned nunits = PACKBUFFERSIZE >> 2;
@@ -1738,8 +1660,7 @@ _AuData32 (aud, data, len)
  * aud->qfree - free the queue of events, called by AuCloseServer
  */
 
-void _AuFreeQ (aud)
-    AuServer *aud;
+void _AuFreeQ (AuServer *aud)
 {
     register _AuQEvent *qelt = aud->qfree;
   
@@ -1769,9 +1690,7 @@ void _AuFreeQ (aud)
 /*
  * _AuGetHostname - similar to gethostname but allows special processing.
  */
-int _AuGetHostname (buf, maxlen)
-    char *buf;
-    int maxlen;
+int _AuGetHostname (char *buf, int maxlen)
 {
     int len;
 
@@ -1799,8 +1718,7 @@ int _AuGetHostname (buf, maxlen)
  * This is a macro if MSKCNT <= 4
  */
 int
-_AuANYSET(src)
-    AuInt32	*src;
+_AuANYSET(AuInt32 *src)
 {
     int i;
 
@@ -1819,38 +1737,32 @@ _AuANYSET(src)
  */
 #include <sys/socket.h>
 
-int _AuReadV (fd, iov, iovcnt)
-int fd;
-struct iovec *iov;
-int iovcnt;
+int _AuReadV (int fd, struct iovec *iov, int iovcnt)
 {
-	struct msghdr hdr;
-
-	hdr.msg_iov = iov;
-	hdr.msg_iovlen = iovcnt;
-	hdr.msg_accrights = 0;
-	hdr.msg_accrightslen = 0;
-	hdr.msg_name = 0;
-	hdr.msg_namelen = 0;
-
-	return (recvmsg (fd, &hdr, 0));
+  struct msghdr hdr;
+  
+  hdr.msg_iov = iov;
+  hdr.msg_iovlen = iovcnt;
+  hdr.msg_accrights = 0;
+  hdr.msg_accrightslen = 0;
+  hdr.msg_name = 0;
+  hdr.msg_namelen = 0;
+  
+  return (recvmsg (fd, &hdr, 0));
 }
 
-int _AuWriteV (fd, iov, iovcnt)
-int fd;
-struct iovec *iov;
-int iovcnt;
+int _AuWriteV (int fd, struct iovec *iov, int iovcnt)
 {
-	struct msghdr hdr;
-
-	hdr.msg_iov = iov;
-	hdr.msg_iovlen = iovcnt;
-	hdr.msg_accrights = 0;
-	hdr.msg_accrightslen = 0;
-	hdr.msg_name = 0;
-	hdr.msg_namelen = 0;
-
-	return (sendmsg (fd, &hdr, 0));
+  struct msghdr hdr;
+  
+  hdr.msg_iov = iov;
+  hdr.msg_iovlen = iovcnt;
+  hdr.msg_accrights = 0;
+  hdr.msg_accrightslen = 0;
+  hdr.msg_name = 0;
+  hdr.msg_namelen = 0;
+  
+  return (sendmsg (fd, &hdr, 0));
 }
 
 #endif /* CRAY */
@@ -1864,61 +1776,55 @@ int iovcnt;
 #include <sys/uio.h>
 #endif /* !WIN32 */
 
-int _AuReadV (fd, iov, iovcnt)
-int fd;
-struct iovec *iov;
-int iovcnt;
+int _AuReadV (int fd, struct iovec *iov, int iovcnt)
 {
-    int i, len, total;
-    char *base;
-
-    errno = 0;
-    for (i=0, total=0;  i<iovcnt;  i++, iov++) {
-	len = iov->iov_len;
-	base = iov->iov_base;
-	while (len > 0) {
-	    register int nbytes;
+  int i, len, total;
+  char *base;
+  
+  errno = 0;
+  for (i=0, total=0;  i<iovcnt;  i++, iov++) {
+    len = iov->iov_len;
+    base = iov->iov_base;
+    while (len > 0) {
+      register int nbytes;
 #ifndef WIN32
-	    nbytes = read(fd, base, len);
+      nbytes = read(fd, base, len);
 #else /* WIN32 */
-	    nbytes = recv(fd, base, len, 0);
+      nbytes = recv(fd, base, len, 0);
 #endif /* WIN32 */
-	    if (nbytes < 0 && total == 0)  return -1;
-	    if (nbytes <= 0)  return total;
-	    errno = 0;
-	    len   -= nbytes;
-	    total += nbytes;
-	    base  += nbytes;
-	}
+      if (nbytes < 0 && total == 0)  return -1;
+      if (nbytes <= 0)  return total;
+      errno = 0;
+      len   -= nbytes;
+      total += nbytes;
+      base  += nbytes;
     }
-    return total;
+  }
+  return total;
 }
 
 #ifdef WIN32
-int _AuWriteV (fd, iov, iovcnt)
-int fd;
-struct iovec *iov;
-int iovcnt;
+int _AuWriteV (int fd, struct iovec *iov, int iovcnt)
 {
-    int i, len, total;
-    char *base;
-
-    errno = 0;
-    for (i=0, total=0;  i<iovcnt;  i++, iov++) {
-	len = iov->iov_len;
-	base = iov->iov_base;
-	while (len > 0) {
-	    register int nbytes;
-	    nbytes = send(fd, base, len, 0);
-	    if (nbytes < 0 && total == 0)  return -1;
-	    if (nbytes <= 0)  return total;
-	    errno = 0;
-	    len   -= nbytes;
-	    total += nbytes;
-	    base  += nbytes;
-	}
+  int i, len, total;
+  char *base;
+  
+  errno = 0;
+  for (i=0, total=0;  i<iovcnt;  i++, iov++) {
+    len = iov->iov_len;
+    base = iov->iov_base;
+    while (len > 0) {
+      register int nbytes;
+      nbytes = send(fd, base, len, 0);
+      if (nbytes < 0 && total == 0)  return -1;
+      if (nbytes <= 0)  return total;
+      errno = 0;
+      len   -= nbytes;
+      total += nbytes;
+      base  += nbytes;
     }
-    return total;
+  }
+  return total;
 }
 #endif /* WIN32 */
 
@@ -1974,90 +1880,84 @@ static char workarea[MAX_WORKAREA];
 
 
 int
-_AuReadV (fd, v, n)
-    int		fd;
-    struct iovec v[];
-    int		n;
+_AuReadV (int fd, struct iovec v[], int n)
 {
-	int i, rc, len, size = 0;
-	char * buf = workarea;
-	char * p;
-
-	if (n <= 0 || n > 16)
-	{
-		errno = EINVAL;
-		return (-1);
-	}
-	for (i = 0; i < n; ++i)
-	{
-		if ((len = v[i].iov_len) < 0 || v[i].iov_base == NULL)
-		{
-			errno = EINVAL;
-			return (-1);
-		}
-		size += len;
-	}
-	if ((size > MAX_WORKAREA) && ((buf = malloc (size)) == NULL))
-	{
-		errno = EINVAL;
-		return (-1);
-	}
-	if((rc = (*_AusStream[_AusTypeOfStream[fd]].ReadFromStream)(fd, buf, size,
-							     BUFFERING))> 0)
-	{
-		for (i = 0, p = buf; i < n; ++i)
-		{
-			memcpy (v[i].iov_base, p, len = v[i].iov_len);
-			p += len;
-		}
-	}
-	if (size > MAX_WORKAREA)
-		free (buf);
-
-	return (rc);
+  int i, rc, len, size = 0;
+  char * buf = workarea;
+  char * p;
+  
+  if (n <= 0 || n > 16)
+    {
+      errno = EINVAL;
+      return (-1);
+    }
+  for (i = 0; i < n; ++i)
+    {
+      if ((len = v[i].iov_len) < 0 || v[i].iov_base == NULL)
+        {
+          errno = EINVAL;
+          return (-1);
+        }
+      size += len;
+    }
+  if ((size > MAX_WORKAREA) && ((buf = malloc (size)) == NULL))
+    {
+      errno = EINVAL;
+      return (-1);
+    }
+  if((rc = (*_AusStream[_AusTypeOfStream[fd]].ReadFromStream)(fd, buf, size,
+                                                              BUFFERING))> 0)
+    {
+      for (i = 0, p = buf; i < n; ++i)
+        {
+          memcpy (v[i].iov_base, p, len = v[i].iov_len);
+          p += len;
+        }
+    }
+  if (size > MAX_WORKAREA)
+    free (buf);
+  
+  return (rc);
 }
 
 int
-_AuWriteV (fd, v, n)
-    int fd;
-    struct iovec v[];
-    int n;
+_AuWriteV (int fd, struct iovec v[], int n)
 {
-	int i, rc, len, size = 0;
-	char * buf = workarea;
-	char * p;
-
-	if (n <= 0 || n > 16)
-	{
-		errno = EINVAL;
-		return (-1);
-	}
-	for (i = 0; i < n; ++i)
-	{
-		if ((len = v[i].iov_len) < 0 || v[i].iov_base == NULL)
-		{
-			errno = EINVAL;
-			return (-1);
-		}
-		size += len;
-	}
-
-	if ((size > MAX_WORKAREA) && ((buf = malloc (size)) == NULL))
-	{
-		errno = EINVAL;
-		return (-1);
-	}
-	for (i = 0, p = buf; i < n; ++i)
-	{
-		memcpy (p, v[i].iov_base, len = v[i].iov_len);
-		p += len;
-	}
-	rc = (*_AusStream[_AusTypeOfStream[fd]].WriteToStream)(fd, buf, size);
-
-	if (size > MAX_WORKAREA)
-		free (buf);
-
-	return (rc);
+  int i, rc, len, size = 0;
+  char * buf = workarea;
+  char * p;
+  
+  if (n <= 0 || n > 16)
+    {
+      errno = EINVAL;
+      return (-1);
+    }
+  for (i = 0; i < n; ++i)
+    {
+      if ((len = v[i].iov_len) < 0 || v[i].iov_base == NULL)
+        {
+          errno = EINVAL;
+          return (-1);
+        }
+      size += len;
+    }
+  
+  if ((size > MAX_WORKAREA) && ((buf = malloc (size)) == NULL))
+    {
+      errno = EINVAL;
+      return (-1);
+    }
+  for (i = 0, p = buf; i < n; ++i)
+    {
+      memcpy (p, v[i].iov_base, len = v[i].iov_len);
+      p += len;
+    }
+  rc = (*_AusStream[_AusTypeOfStream[fd]].WriteToStream)(fd, buf, size);
+  
+  if (size > MAX_WORKAREA)
+    free (buf);
+  
+  return (rc);
 }
 
 
@@ -2066,29 +1966,21 @@ _AuWriteV (fd, v, n)
 
 #ifndef HAS_FAKE_IOV
 int
-_AuReadV (fd, v, n)
-    int		fd;
-    struct iovec v[];
-    int		n;
+_AuReadV (int fd, struct iovec v[], int n)
 {
-	return(readv(fd, v, n));
+  return(readv(fd, v, n));
 }
 
 int
-_AuWriteV (fd, v, n)
-    int fd;
-    struct iovec v[];
-    int n;
+_AuWriteV (int fd, struct iovec v[], int n)
 {
-	return(writev(fd, v, n));
+  return(writev(fd, v, n));
 }
 #endif /* HAS_FAKE_IOV */
 
 AuSyncHandlerRec *
-AuRegisterSyncHandler(aud, callback, data)
-AuServer       *aud;
-AuSyncHandlerCallback callback;
-AuPointer       data;
+AuRegisterSyncHandler(AuServer *aud, AuSyncHandlerCallback callback, 
+                      AuPointer data)
 {
     AuSyncHandlerRec *handler;
 
@@ -2104,17 +1996,14 @@ AuPointer       data;
 }
 
 void
-AuUnregisterSyncHandler(aud, handler)
-AuServer       *aud;
-AuSyncHandlerRec *handler;
+AuUnregisterSyncHandler(AuServer *aud, AuSyncHandlerRec *handler)
 {
     _AuRemoveFromLinkedList(aud->synchandler, handler);
     Aufree(handler);
 }
 
 void
-_AuDoSyncHandle(aud)
-AuServer       *aud;
+_AuDoSyncHandle(AuServer *aud)
 {
     AuSyncHandlerRec *p = aud->synchandler,
                    *next;
