@@ -136,11 +136,20 @@ static struct conntype {
 
 #endif /* CLIENTS_LOCALCONN */
 
-static void GetAuthorization();
+static void
+GetAuthorization(
+                 int fd,
+                 int family,
+                 int saddrlen,
+                 int iserver,
+                 char *saddr,
+                 char **auth_namep,			/* RETURN */
+                 int *auth_namelenp,			/* RETURN */
+                 char **auth_datap,			/* RETURN */
+                 int *auth_datalenp			/* RETURN */
+                 );
 
-static char *copystring (src, len)
-    register _AuConst char *src;
-    int len;
+static char *copystring (register const char *src, int len)
 {
     char *dst = Aumalloc (len + 1);
 
@@ -154,8 +163,7 @@ static char *copystring (src, len)
 
 #ifdef STARTSERVER
 static int
-_AuIsLocal(name)
-	char *name;
+_AuIsLocal(char *name)
 {
 	struct hostent *hp, hs, *thp;
 	char **ap, addr[4];
@@ -188,11 +196,11 @@ _AuIsLocal(name)
 }
 
 static int
-_AuIsAudioOK()
+_AuIsAudioOK(void)              /* JET - what is this doing here?? */
 {
-	if (access("/dev/audio", R_OK|W_OK) < 0)
-		return(AuFalse);
-	return(AuTrue);
+  if (access("/dev/audio", R_OK|W_OK) < 0)
+    return(AuFalse);
+  return(AuTrue);
 }
 
 #include <signal.h>
@@ -204,19 +212,22 @@ static int _AuServerUp;
 
 /*ARGSUSED*/
 static void
-_AuServerWait(sig)
-	int sig;
+_AuServerWait(int sig)
 {
-	if (_AuServerUp == AuFalse)
-		_AuServerUp = AuTrue;
+  if (_AuServerUp == AuFalse)
+    _AuServerUp = AuTrue;
 }
 
 static int
-_AuStartServer(iserver)
-	int iserver;
+_AuStartServer(int iserver, AuBool xname)
+
 {
 	pid_t pid;
 
+#ifdef DEBUG	
+	fprintf(stderr, "_AuStartServer: starting, xname = %d, iserver = %d\n", xname, iserver);
+#endif
+
 	if ((pid = fork()) != 0) {
 		int status;
 		/* parent -- wait for child */
@@ -245,7 +256,20 @@ _AuStartServer(iserver)
 	else {
 	  char arg1[80];	/* hmmm. */
 
+        /* JET 1/20/2002 - need to handle cases where server number is
+           a port number and not a 'display' number...  If iserver is
+           => to the default AU port, convert to display number... */
+
+	  if (xname == AuFalse)
+	    iserver -= AU_DEFAULT_TCP_PORT;
+	  
 	  sprintf(arg1,":%d",iserver);
+
+#ifdef DEBUG
+	fprintf(stderr, "_AuStartServer: getting ready to exec: "
+		"xname = %d, iserver = %d, arg1 = '%s'\n", 
+		xname, iserver, arg1);
+#endif
 	/* grandchild -- start server */
 	(void)signal(SIGUSR1, SIG_IGN);
 	/* start server.  Ideally the command should be set by some resource */
@@ -281,23 +305,23 @@ _AuStartServer(iserver)
  *     o  UNIX domain socket
  *     o  TCP to local host
  */
-int _AuConnectServer (server_name, fullnamep, svrnump, 
-		      auth_namep, auth_namelenp, auth_datap, auth_datalenp)
-    _AuConst char *server_name;
-    char **fullnamep;			/* RETURN */
-    int *svrnump;			/* RETURN */
-    char **auth_namep;			/* RETURN */
-    int *auth_namelenp;			/* RETURN */
-    char **auth_datap;			/* RETURN */
-    int *auth_datalenp;			/* RETURN */
+int _AuConnectServer (
+    const char *server_name,
+    char **fullnamep,			/* RETURN */
+    int *svrnump,			/* RETURN */
+    char **auth_namep,			/* RETURN */
+    int *auth_namelenp,			/* RETURN */
+    char **auth_datap,			/* RETURN */
+    int *auth_datalenp			/* RETURN */
+    )
 {
     int family;
     int saddrlen;
     char *saddr;
-    _AuConst char *lastp, *p;		/* char pointers */
+    const char *lastp, *p;		/* char pointers */
     char *phostname = NULL;		/* start of host of server */
     char *psvrnum = NULL;		/* start of svrnum of server */
-    char *realtrans;			/* real audio transport prefix */
+    const char *realtrans;		/* real audio transport prefix */
     char newsvrnum[10];			/* in case need to convert from X */
     int saviserver;			/* a temp variable */
     AuBool xname = AuTrue;		/* most applications it will be */
@@ -311,18 +335,26 @@ int _AuConnectServer (server_name, fullnamep, svrnump,
     saddrlen = 0;			/* set so that we can clear later */
     saddr = NULL;
 
+
+#ifdef DEBUG
+    if (server_name)
+      fprintf(stderr, "_AuConnectServer: SERVERNAME = %s\n", server_name);
+    else
+      fprintf(stderr, "_AuConnectServer: SERVERNAME = NULL\n");
+#endif
     /*
      * Step 0, see if it is an audio server name or an X display name.
      */
     for (p = server_name; *p; p++) {
-	if (*p == '/') {
+
+      if (*p == '/') {
 	    int len = (p - server_name);
 	    char tmptransport[41];
-	    register _AuConst char *src;
+	    register const char *src;
 	    register char *dst;
 
 	    if (len >= sizeof tmptransport)    /* too AuInt32 */
-		goto bad;
+	      goto bad;
 	    src = server_name;
 	    dst = tmptransport;
 	    while (src < p) {
@@ -331,11 +363,12 @@ int _AuConnectServer (server_name, fullnamep, svrnump,
 	    }
 	    *dst = '\0';
 	    if (strcmp (tmptransport, "tcp") == 0 ||
-		strcmp (tmptransport, "decnet") == 0) {
+		strcmp (tmptransport, "decnet") == 0) 
+	      {
 		xname = AuFalse;	/* got a real name! */
 		server_name = (p + 1);	  /* skip prefix */
 		break;
-	    }
+	      }
 	}
     }
 
@@ -344,7 +377,9 @@ int _AuConnectServer (server_name, fullnamep, svrnump,
      * first colon.
      */
     /* SUPPRESS 530 */
-    for (lastp = p = server_name; *p && *p != ':'; p++) ;
+    for (lastp = p = server_name; *p && *p != ':'; p++) 
+      ;
+
     if (!*p) return -1;		/* must have a colon */
 
     if (p != lastp) {		/* no hostname given */
@@ -376,13 +411,19 @@ int _AuConnectServer (server_name, fullnamep, svrnump,
      */
 
     /* SUPPRESS 530 */
-    for (lastp = ++p; *p && isascii(*p) && isdigit(*p); p++) ;
+    for (lastp = ++p; *p && isascii(*p) && isdigit(*p); p++) 
+      ;
+
     if ((p == lastp) ||			 /* required field */
 	((*p != '.') && (*p != '\0')) || /* invalid non-digit terminator */
 	!(psvrnum = copystring (lastp, p - lastp)))  /* no memory */
       goto bad;
+
     saviserver = iserver = atoi (psvrnum);
 
+#ifdef DEBUG
+    fprintf(stderr, "_AuConnectServer: saviserver = %d\n", saviserver);
+#endif
 
     /*
      * At this point, we know the following information:
@@ -512,7 +553,6 @@ int _AuConnectServer (server_name, fullnamep, svrnump,
     }
 #undef LOCALCONNECTION
 
-
     /*
      * Make the connection, also need to get the auth address info for
      * non-local connections.  Do retries in case server host has hit its
@@ -523,12 +563,22 @@ int _AuConnectServer (server_name, fullnamep, svrnump,
     if ((fd = (*connfunc) (phostname, &iserver, xname, AU_CONNECTION_RETRIES,
 			   &family, &saddrlen, &saddr)) < 0)
 #ifndef STARTSERVER
-		goto bad;
+      {
+# ifdef DEBUG
+        fprintf(stderr, "connfunc() failed, returned %d\n", fd );
+# endif
+        goto bad;
+      }
 #else /* STARTSERVER */
     {
-	/* if local connection, try to start up a server */
-	if (!_AuIsLocal(phostname) || !_AuIsAudioOK() || !_AuStartServer(iserver))
+      /* if local connection, try to start up a server */
+
+      /* JET - 2/23/2002 - need to use saviserver for AuStartServer since
+	 connfunc() may have changed iserver */
+	if (!_AuIsLocal(phostname) || !_AuIsAudioOK() || 
+	    !_AuStartServer(saviserver, xname))
 	    goto bad;
+
 	/* try again */
 	iserver = saviserver;
     	if ((fd = (*connfunc) (phostname, &iserver, xname, /* again */
@@ -536,6 +586,11 @@ int _AuConnectServer (server_name, fullnamep, svrnump,
 	    goto bad;
     }
 #endif /* STARTSERVER */
+
+#ifdef DEBUG
+    fprintf(stderr, "_AuConnectServer: fd = %d\n", fd);
+#endif
+
 #ifndef WIN32
     if (fd >= OPEN_MAX)
 	goto bad;
@@ -581,6 +636,9 @@ int _AuConnectServer (server_name, fullnamep, svrnump,
 	if (psvrnum) Aufree (psvrnum);
 	psvrnum = newsvrnum;
     }
+#ifdef DEBUG
+    fprintf(stderr, "_AuConnectServer: newsvrnum = '%s'\n", newsvrnum);
+#endif
 
     switch (family) {
       case AuNetworkInternet:
@@ -612,8 +670,13 @@ int _AuConnectServer (server_name, fullnamep, svrnump,
     if (phostname) Aufree (phostname);
     if (psvrnum && psvrnum != newsvrnum) Aufree (psvrnum);
 
-    GetAuthorization(fd, family, saddr, saddrlen, saviserver,
-		     auth_namep, auth_namelenp, auth_datap, auth_datalenp);
+    GetAuthorization(fd, family, saddrlen, saviserver,
+		     saddr, auth_namep, auth_namelenp, auth_datap, 
+                     auth_datalenp);
+#ifdef DEBUG
+    fprintf(stderr, "_AuConnectServer: after GetAuthorization, fd = %d, saddr = %p\n", fd, saddr);
+#endif
+
     return fd;
 
 
@@ -621,6 +684,9 @@ int _AuConnectServer (server_name, fullnamep, svrnump,
      * error return; make sure everything is cleaned up.
      */
   bad:
+#if defined(DEBUG)
+    fprintf(stderr, "_AuConnectServer: fd = %d, BAD return -1\n", fd);
+#endif
     if (fd >= 0) (void) close (fd);
     if (saddr) Aufree (saddr);
     if (phostname) Aufree (phostname);
@@ -685,15 +751,15 @@ int _AuConnectServer (server_name, fullnamep, svrnump,
 
 #ifdef DNETCONN
 /* ARGSUSED */
-static int MakeDECnetConnection (phostname, iserverp, xname, retries,
-				 familyp, saddrlenp, saddrp)
-    char *phostname;
-    int *iserverp;			/* can be RETURN */
-    AuBool xname;
-    int retries;
-    int *familyp;			/* RETURN */
-    int *saddrlenp;			/* RETURN */
-    char **saddrp;			/* RETURN */
+static int MakeDECnetConnection (
+                                 char *phostname,
+                                 int *iserverp, /* can be RETURN */
+                                 AuBool xname,
+                                 int retries,
+                                 int *familyp, /* RETURN */
+                                 int *saddrlenp, /* RETURN */
+                                 char **saddrp /* RETURN */
+                                 )
 {
     int fd;
     char objname[20];
@@ -703,6 +769,10 @@ static int MakeDECnetConnection (phostname, iserverp, xname, retries,
 
     if (!phostname) phostname = "0";
 
+#ifdef DEBUG
+    fprintf(stderr, "MakeDECnetConnection: starting\n");
+#endif
+
     /*
      * build the target object name.
      */
@@ -744,15 +814,15 @@ static int MakeDECnetConnection (phostname, iserverp, xname, retries,
 #include <sys/un.h>
 
 /*ARGSUSED*/
-static int MakeUNIXSocketConnection (phostname, iserverp, xname, retries,
-				     familyp, saddrlenp, saddrp)
-    char *phostname;
-    int *iserverp;			/* can be RETURN */
-    AuBool xname;
-    int retries;
-    int *familyp;			/* RETURN */
-    int *saddrlenp;			/* RETURN */
-    char **saddrp;			/* RETURN */
+static int MakeUNIXSocketConnection (
+    char *phostname,
+    int *iserverp,			/* can be RETURN */
+    AuBool xname,
+    int retries,
+    int *familyp,			/* RETURN */
+    int *saddrlenp,			/* RETURN */
+    char **saddrp			/* RETURN */
+    )
 {
     struct sockaddr_un unaddr;		/* UNIX socket data block */
     struct sockaddr *addr;		/* generic socket pointer */
@@ -777,15 +847,29 @@ static int MakeUNIXSocketConnection (phostname, iserverp, xname, retries,
     addrlen = strlen(unaddr.sun_path) + sizeof(unaddr.sun_family);
 #endif
   
+#ifdef DEBUG
+    fprintf(stderr, "MakeUNIXSocketConnection: starting, *iserverp = %d\n",
+	    *iserverp);
+#endif
+
     /*
      * Open the network connection.
      */
     do {
 	if ((fd = socket ((int) addr->sa_family, SOCK_STREAM, 0)) < 0) {
+#ifdef DEBUG
+          fprintf(stderr,
+                  "MakeUNIXSocketConnection: socket errno = %d\n", errno);
+#endif
+
 	    return -1;
 	}
 
 	if (connect (fd, addr, addrlen) < 0) {
+#ifdef DEBUG
+          fprintf(stderr,
+                  "MakeUNIXSocketConnection: connect errno = %d\n", errno);
+#endif
 	    int olderrno = errno;
 	    (void) close (fd);
 #ifdef hpux /* this is disgusting */
@@ -801,6 +885,11 @@ static int MakeUNIXSocketConnection (phostname, iserverp, xname, retries,
 #endif
 	    if (olderrno != ENOENT || retries <= 0) {
 		errno = olderrno;
+#ifdef DEBUG
+                fprintf(stderr, 
+                        "MakeUNIXSocketConnection: errno = %d\n", errno);
+#endif
+
 		return -1;
 	    }
 	    sleep (1);
@@ -812,21 +901,22 @@ static int MakeUNIXSocketConnection (phostname, iserverp, xname, retries,
     /*
      * Don't need to get auth info since we're local
      */
+
     return fd;
 }
 #endif /* UNIXCONN */
 
 
 #ifdef TCPCONN
-static int MakeTCPConnection (phostname, iserverp, xname, retries,
-			      familyp, saddrlenp, saddrp)
-    char *phostname;
-    int *iserverp;			/* can be RETURN */
-    AuBool xname;
-    int retries;
-    int *familyp;			/* RETURN */
-    int *saddrlenp;			/* RETURN */
-    char **saddrp;			/* RETURN */
+static int MakeTCPConnection (
+    char *phostname,
+    int *iserverp,			/* can be RETURN */
+    AuBool xname,
+    int retries,
+    int *familyp,			/* RETURN */
+    int *saddrlenp,			/* RETURN */
+    char **saddrp			/* RETURN */
+    )
 {
     char hostnamebuf[256];		/* tmp space */
 #ifndef _MINIX
@@ -860,12 +950,20 @@ static int MakeTCPConnection (phostname, iserverp, xname, retries,
 
 #define INVALID_INETADDR ((AuUint32) -1)
 
+#ifdef DEBUG
+    fprintf(stderr, "MakeTCPConnection: starting\n");
+#endif
+
     if (!phostname) {
 	hostnamebuf[0] = '\0';
 	(void) _AuGetHostname (hostnamebuf, sizeof hostnamebuf);
 	phostname = hostnamebuf;
     }
 
+#ifdef DEBUG
+    fprintf(stderr, "MakeTCPConnection: phostname = '%s'\n",
+	    phostname);
+#endif
     /*
      * if numeric host name then try to parse it as such; do the number
      * first because some systems return garbage instead of INVALID_INETADDR
@@ -1078,8 +1176,7 @@ static char Def_Local_Search[] = "SCO:USL:UNIX";
 static char Def_Local_Search[] = "USL:UNIX";
 #endif /* ATT */
 
-static int ParseLocalName(name)
-    char *name;
+static int ParseLocalName(char *name)
 {
     struct conntype *p;
 
@@ -1093,20 +1190,19 @@ static int ParseLocalName(name)
     return(TYPE_INVALID);
 }
 
-static void _dummy(temp)
-    int temp;
+static void _dummy(int temp)
 {
     return;
 }
 
-static int MakeLOCALConnection (phostname, iserverp, retries,
-				familyp, saddrlenp, saddrp)
-    char *phostname;
-    int *iserverp;			/* can be RETURN */
-    int retries;
-    int *familyp;			/* RETURN */
-    int *saddrlenp;			/* RETURN */
-    char **saddrp;			/* RETURN */
+static int MakeLOCALConnection (
+    char *phostname,
+    int *iserverp,			/* can be RETURN */
+    int retries,
+    int *familyp,			/* RETURN */
+    int *saddrlenp,			/* RETURN */
+    char **saddrp			/* RETURN */
+  )
 {
     int fds, fd, server, fl, ret;
     unsigned alarm_time;
@@ -1122,6 +1218,11 @@ static int MakeLOCALConnection (phostname, iserverp, retries,
     struct strbuf ctlbuf;
 #endif
 
+#ifdef DEBUG
+    fprintf(stderr, "MakeLOCALConnection: starting, LocalConnType = %d\n",
+	    LocalConnType);
+#endif
+
     /*
      * Get list of local connection modes to try.
      */
@@ -1150,6 +1251,10 @@ static int MakeLOCALConnection (phostname, iserverp, retries,
 	switch (ParseLocalName(to_try)) {
 	case TYPE_UNIX:
 #ifdef UNIXCONN
+
+# ifdef DEBUG
+    fprintf(stderr, "connect TYPE_UNIX\n");
+# endif
     	    fd = MakeUNIXSocketConnection(phostname, iserverp, retries,
 				          familyp, saddrlenp, saddrp);
 	    if (fd >= 0)
@@ -1326,13 +1431,14 @@ char *getenv();
 void XAmReaderThread();
 
 static int
-MakeAmConnection(phostname, iserverp, retries, familyp, saddrlenp, saddrp)
-    char *phostname;
-    int *iserverp;			/* can be RETURN */
-    int retries;
-    int *familyp;			/* RETURN */
-    int *saddrlenp;			/* RETURN */
-    char **saddrp;			/* RETURN */
+MakeAmConnection(
+    char *phostname,
+    int *iserverp,			/* can be RETURN */
+    int retries,
+    int *familyp,			/* RETURN */
+    int *saddrlenp,			/* RETURN */
+    char **saddrp			/* RETURN */
+    )
 {
     capability xservercap;
     char xserverpath[256];
@@ -1348,7 +1454,7 @@ MakeAmConnection(phostname, iserverp, retries, familyp, saddrlenp, saddrp)
     /* allocate channel descriptor */
     chandesc = XAmAllocChanDesc();
     if (chandesc == (XAmChanDesc *)NULL) {
-	fprintf(stderr, "audiolib: Out of channel capabilities\n");
+	fprintf(stderr, "audiolib: Out of channel memory\n");
 	return -1;
     }
 
@@ -1508,10 +1614,7 @@ MakeAmConnection(phostname, iserverp, retries, familyp, saddrlenp, saddrp)
  * Disconnect from server.
  */
 
-int _AuDisconnectServer (server)
-
-    int server;
-
+int _AuDisconnectServer (int server)
 {
 #ifdef AMOEBA
     register XAmChanDesc *chandesc;
@@ -1539,10 +1642,12 @@ int _AuDisconnectServer (server)
 static int padlength[4] = {0, 3, 2, 1};	 /* make sure auth is multiple of 4 */
 
 AuBool
-_AuSendClientPrefix (aud, client, auth_proto, auth_string)
-     AuServer *aud;
-     auConnClientPrefix *client;	/* contains count for auth_* */
-     char *auth_proto, *auth_string;	/* NOT null-terminated */
+_AuSendClientPrefix (
+     AuServer *aud,
+     auConnClientPrefix *client,	/* contains count for auth_* */
+     char *auth_proto, 
+     char *auth_string	/* NOT null-terminated */
+     )
 {
     int auth_length = client->nbytesAuthProto;
     int auth_strlen = client->nbytesAuthString;
@@ -1673,11 +1778,12 @@ static int default_xauth_lengths[] = {
  * Create a credential that we can send to the X server.
  */
 static int
-auth_ezencode(servername, window, cred_out, len)
-        char           *servername;
-        int             window;
-	char	       *cred_out;
-        int            *len;
+auth_ezencode(
+        char           *servername,
+        int             window,
+	char	       *cred_out,
+        int            *len
+        )
 {
         AUTH           *a;
         XDR             xdr;
@@ -1699,54 +1805,19 @@ auth_ezencode(servername, window, cred_out, len)
 }
 #endif
 
-#if XlibSpecificationRelease < 5
-/* pre-X11R5 compatability */
-
-Xauth *XauGetBestAuthByAddr(
-#if NeedFunctionPrototypes
-#ifndef _Xconst
-#if __STDC__ || defined(__cplusplus) || defined(c_plusplus) || (FUNCPROTO&4)
-#define _Xconst const
-#else
-#define _Xconst
-#endif
-#endif /* _Xconst */
-
-#if NeedWidePrototypes
-unsigned int	/* family */,
-unsigned int	/* address_length */,
-#else
-unsigned short	/* family */,
-unsigned short	/* address_length */,
-#endif
-_Xconst char*	/* address */,
-#if NeedWidePrototypes
-unsigned int	/* number_length */,
-#else
-unsigned short	/* number_length */,
-#endif
-_Xconst char*	/* number */,
-int		/* types_length */,
-char**		/* type_names */,
-_Xconst int*	/* type_lengths */
-#endif
-);
-
-#endif /* XlibSpecificationRelease < 5 */
-
 /* ARGSUSED */
 static void
-GetAuthorization(fd, family, saddr, saddrlen, iserver,
-		 auth_namep, auth_namelenp, auth_datap, auth_datalenp)
-    int fd;
-    int family;
-    int saddrlen;
-    int iserver;
-    char *saddr;
-    char **auth_namep;			/* RETURN */
-    int *auth_namelenp;			/* RETURN */
-    char **auth_datap;			/* RETURN */
-    int *auth_datalenp;			/* RETURN */
+GetAuthorization(
+    int fd,
+    int family,
+    int saddrlen,
+    int iserver,
+    char *saddr,
+    char **auth_namep,			/* RETURN */
+    int *auth_namelenp,			/* RETURN */
+    char **auth_datap,			/* RETURN */
+    int *auth_datalenp			/* RETURN */
+    )
 {
 #ifdef SECURE_RPC
     char rpc_cred[MAX_AUTH_BYTES];
