@@ -1,4 +1,4 @@
-/* $Id: auvoxware.h,v 1.3 2000/03/05 02:40:56 jon Exp $ */
+/* $Id: auvoxware.h 166 2006-07-26 23:56:34Z jon $ */
 /*
    SCCS: @(#) auvoxware.h 11.2 95/03/22 
 */
@@ -28,7 +28,7 @@ PERFORMANCE OF THIS SOFTWARE.
 /*
    SCO Modification History:
    S001, 22-Mar-95, shawnm@sco.com
-	change AuBlockAudio, AuUnBlockAudio, vendor string
+        change AuBlockAudio, AuUnBlockAudio, vendor string
 */
 /*
  * Copyright 1993 Network Computing Devices, Inc. Copyright (C) Siemens
@@ -62,42 +62,42 @@ PERFORMANCE OF THIS SOFTWARE.
 #ifndef _AUVOXWARE_H_
 #define _AUVOXWARE_H_
 
-#define	VENDOR_STRING		"VoxWare"
-#define	VENDOR_RELEASE		1
+#define VENDOR_STRING           "VoxWare"
+#define VENDOR_RELEASE          1
 
 /*
  * NOTE: The native format endianess should match that of the machine
  * running the audio server.
  */
-#define auNativeFormat		AuFormatLinearSigned16LSB
-#define auNativeBytesPerSample	2
+#define auNativeFormat          AuFormatLinearSigned16LSB
+#define auNativeBytesPerSample  2
 
 #include <signal.h>
 
 typedef int AuBlock;
-#if defined(linux) 
+#if defined(linux)  || defined(__CYGWIN__)
 #define        AuBlockAudio()          0
 #define        AuUnBlockAudio(_x)
 #else /* defined(linux)  */
 #ifndef sco
 #if defined(SVR4) || defined(SYSV)
-#define	AuUnBlockAudio(_x)						      \
-do									      \
-{									      \
-    if ((int) (_x) != (int) SIG_HOLD)					      \
-	(void) sigset(SIGALRM, (void (*)(int))(_x));			      \
+#define AuUnBlockAudio(_x)                                                    \
+do                                                                            \
+{                                                                             \
+    if ((int) (_x) != (int) SIG_HOLD)                                         \
+        (void) sigset(SIGALRM, (void (*)(int))(_x));                          \
 } while(0)
 
-#define	AuBlockAudio()		(int) sigset(SIGALRM, SIG_HOLD)
-#define signal			sigset
+#define AuBlockAudio()          (int) sigset(SIGALRM, SIG_HOLD)
+#define signal                  sigset
 #else
-#define	AuUnBlockAudio(_x)	sigsetmask(_x)
-#define	AuBlockAudio()		sigblock(sigmask(SIGALRM))
+#define AuUnBlockAudio(_x)      sigsetmask(_x)
+#define AuBlockAudio()          sigblock(sigmask(SIGALRM))
 #endif
 #endif /* sco */
 #endif /* defined(linux) */
 
-#define AuProtectedMalloc(_s)	xalloc(_s)
-#define AuProtectedFree(_p)	free(_p)
+#define AuProtectedMalloc(_s)   xalloc(_s)
+#define AuProtectedFree(_p)     free(_p)
 
 #endif /* !_AUVOXWARE_H_ */
