@@ -19,6 +19,7 @@
  * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  * 
+ * $Id: utils.c 185 2006-08-26 21:10:33Z jon $
  * $NCDId: @(#)utils.c,v 1.8 1996/04/24 17:16:15 greg Exp $
  */
 /***********************************************************
@@ -50,9 +51,11 @@ SOFTWARE.
 #include <audio/audio.h>
 #include <audio/Aos.h>
 #include <stdio.h>
-#include "nasconfig.h"
+#include <stdlib.h>
+#include "nasconf.h"
 #include "misc.h"
 #include "opaque.h"
+#include "audio/release.h"
 #include <signal.h>
 #if !defined(SYSV) && !defined(AMOEBA) && !defined(_MINIX)
 #include <sys/resource.h>
@@ -77,21 +80,21 @@ SOFTWARE.
 #define sigset  _local_signal
 
 #ifndef NeedFunctionPrototypes
-static void (*_local_signal(sig, action))()
+static void (*_local_signal(sig, action)) ()
 int sig;
-void (*action)();
+void (*action) ();
 #else /* NeedFunctionPrototypes */
-static void (*_local_signal(int sig, void (*action)(int)))(int)
-#endif /* NeedFunctionPrototypes */
+static void (*_local_signal(int sig, void (*action) (int))) (int)
+#endif                          /* NeedFunctionPrototypes */
 {
-        struct sigvec   vec;
-        struct sigvec   ovec;
+    struct sigvec vec;
+    struct sigvec ovec;
 
-        vec.sv_handler = action;
-        vec.sv_flags = 0;
-        sigvector(sig, &vec, &ovec);
+    vec.sv_handler = action;
+    vec.sv_flags = 0;
+    sigvector(sig, &vec, &ovec);
 
-        return(ovec.sv_handler);
+    return (ovec.sv_handler);
 }
 #else
 #define signal sigset
@@ -107,7 +110,6 @@ extern Bool PartialNetwork;
 Bool CoreDump;
 Bool noTestExtensions;
 
-Bool allow_any_host = FALSE;
 #ifdef STARTSERVER
 int timeoutWithNoClients = 0;
 #endif /* STARTSERVER */
@@ -117,23 +119,15 @@ int auditTrailLevel = 1;
 #ifdef AMOEBA
 static mutex print_lock
 #endif
-
 void ddxUseMsg(void);
 
-#if !defined(SVR4) && !defined(hpux) && !defined(linux) && !defined(AMOEBA) && !defined(_MINIX)
-extern char *sbrk();
-#endif
-
-#ifdef AIXV3
-#define AIXFILE "/tmp/aixfile"
-FILE *aixfd;
-int SyncOn  = 0;
-extern int SelectWaitTime;
+#if defined(SVR4) || defined(hpux) || defined(linux) || defined(AMOEBA) || defined(_MINIX)
+#include <unistd.h>
 #endif
 
 #ifdef DEBUG
 #ifndef SPECIAL_MALLOC
-#define MEMBUG
+/*#define MEMBUG - This breaks things with unknown CheckMemory call */
 #endif
 #endif
 
@@ -149,23 +143,21 @@ int userdefinedfontpath = 0;
 
 Bool Must_have_memory = FALSE;
 
-char *dev_tty_from_init = NULL;		/* since we need to parse it anyway */
+char *dev_tty_from_init = NULL; /* since we need to parse it anyway */
 
 /* Force connections to close on SIGHUP from init */
 
-/*ARGSUSED*/
-SIGVAL
-AutoResetServer (sig)
-    int sig;
+ /*ARGSUSED*/ SIGVAL
+AutoResetServer(int sig)
 {
     dispatchException |= DE_RESET;
     isItTimeToYield = TRUE;
 #ifdef GPROF
-    chdir ("/tmp");
-    exit (0);
+    chdir("/tmp");
+    exit(0);
 #endif
 #if defined(USG) || defined(SYSV) || defined(SVR4) || defined(linux) || defined(_MINIX)
-    signal (SIGHUP, AutoResetServer);
+    signal(SIGHUP, AutoResetServer);
 #endif
 #ifdef AMOEBA
     WakeUpMainThread();
@@ -174,17 +166,15 @@ AutoResetServer (sig)
 
 /* Force connections to close and then exit on SIGTERM, SIGINT */
 
-/*ARGSUSED*/
-SIGVAL
-GiveUp(sig)
-    int sig;
+ /*ARGSUSED*/ SIGVAL
+GiveUp(int sig)
 {
 
 #if defined(SYSV) || defined(SVR4) || defined(linux) || defined(_MINIX)
     /*
      * Don't let any additional occurances of thses signals cause
      * premature termination
-    */
+     */
     signal(SIGTERM, SIG_IGN);
     signal(SIGINT, SIG_IGN);
 #endif
@@ -198,22 +188,20 @@ GiveUp(sig)
 
 
 static void
-AbortServer()
+AbortServer(void)
 {
     fflush(stderr);
-    if (CoreDump)
-    {
+    if (CoreDump) {
 #ifdef AMOEBA
-	IOPCleanUp();
+        IOPCleanUp();
 #endif
-	abort();
+        abort();
     }
-    exit (1);
+    exit(1);
 }
 
 void
-Error(str)
-    char *str;
+Error(char *str)
 {
 #ifdef AMOEBA
     mu_lock(&print_lock);
@@ -227,136 +215,150 @@ Error(str)
 #ifndef DDXTIME
 #ifndef AMOEBA
 long
-GetTimeInMillis()
+GetTimeInMillis(void)
 {
-    struct timeval  tp;
+    struct timeval tp;
 
     gettimeofday(&tp, 0);
-    return(tp.tv_sec * 1000) + (tp.tv_usec / 1000);
+    return (tp.tv_sec * 1000) + (tp.tv_usec / 1000);
 }
 #else
 long
-GetTimeInMillis()
+GetTimeInMillis(void)
 {
     return sys_milli();
 }
 #endif /* AMOEBA */
 #endif
 
-AdjustWaitForDelay (waitTime, newdelay)
-    pointer	    waitTime;
-    unsigned long   newdelay;
-{
-    static struct timeval   delay_val;
-    struct timeval	    **wt = (struct timeval **) waitTime;
-    unsigned long	    olddelay;
-
-    if (*wt == NULL)
-    {
-	delay_val.tv_sec = newdelay / 1000;
-	delay_val.tv_usec = 1000 * (newdelay % 1000);
-	*wt = &delay_val;
-    }
-    else
-    {
-	olddelay = (*wt)->tv_sec * 1000 + (*wt)->tv_usec / 1000;
-	if (newdelay < olddelay)
-	{
-	    (*wt)->tv_sec = newdelay / 1000;
-	    (*wt)->tv_usec = 1000 * (newdelay % 1000);
-	}
-    }
-}
-
-void UseMsg()
+void
+UseMsg(void)
 {
     ErrorF("Usage: nasd [:<listen port offset>] [option]\n");
-    ErrorF(" -aa		allow any host to connect\n");
-#ifndef AMOEBA
-#ifdef PART_NET
-    ErrorF(" -pn		partial networking enabled [default]\n");
-    ErrorF(" -nopn		partial networking disabled\n");
-#else
-    ErrorF(" -pn		partial networking enabled\n");
-    ErrorF(" -nopn		partial networking disabled [default]\n");
-#endif
-#endif
+    ErrorF(" -aa                allow any client to connect\n");
+    ErrorF(" -local             allow local clients only\n");
+    ErrorF(" -b                 detach and run in background\n");
     ErrorF(" -v                 enable verbose messages\n");
     ErrorF(" -d <num>           enable debug messages at level <num>\n");
-    ddaUseMsg();		/* print dda specific usage */
+    ErrorF(" -config <file>     use <file> as the nasd config file\n");
+    ErrorF(" -V                 print version and exit (ignores other opts)\n");
+#ifndef AMOEBA
+#ifdef PART_NET
+    ErrorF(" -pn                partial networking enabled [default]\n");
+    ErrorF(" -nopn              partial networking disabled\n");
+#else
+    ErrorF(" -pn                partial networking enabled\n");
+    ErrorF(" -nopn              partial networking disabled [default]\n");
+#endif
+#endif
+    ddaUseMsg();                /* print dda specific usage */
 }
 
+/* 
+ * This function parses the command line to check if a non-default
+ * config file has been specified. This needs to be separate from the
+ * normal command-line processing below because we _only_ want to grab
+ * the config file name. Other options need to be read from the config
+ * file and (potentially) overridden by command-line options later.
+ */
+char *
+FindConfigFile(int argc, char *argv[])
+{
+    int i;
+
+    for (i = 1; i < argc; i++) {
+        if (strcmp(argv[i], "-config") == 0) {
+            i++;
+            if (i < argc)
+                return argv[i];
+            else {
+                UseMsg();
+                exit(1);
+            }
+        }
+    }
+    return NULL;                /* Not found */
+}
+
+
 /*
  * This function parses the command line. Handles device-independent fields
  * and allows ddx to handle additional fields.  It is not allowed to modify
  * argc or any of the strings pointed to by argv.
  */
 void
-ProcessCommandLine ( argc, argv )
-int	argc;
-char	*argv[];
+ProcessCommandLine(int argc, char *argv[])
 {
-     int	i;
+    int i;
 #ifndef AMOEBA
 #ifdef PART_NET
-     PartialNetwork = TRUE;
+    PartialNetwork = TRUE;
 #endif
 #endif
 
-     for (i = 1; i < argc; i++) {
-	if (argv[i][0] == ':') {
-	    display = argv[i];
-	    display++;
-	} else if (strcmp(argv[i], "-aa") == 0)
-	    allow_any_host = TRUE;
+    for (i = 1; i < argc; i++) {
+        if (argv[i][0] == ':') {
+            display = argv[i];
+            display++;
+        } else if (strcmp(argv[i], "-aa") == 0)
+            NasConfig.AllowAny = TRUE;
 #ifdef STARTSERVER
-	else if (strcmp(argv[i], "-timeout") == 0) {
-	    i++;
-	    if (i < argc)
-		timeoutWithNoClients = atoi(argv[i]);
-	    else {
-		UseMsg();
-		exit(1);
-	    }
-	}
+        else if (strcmp(argv[i], "-timeout") == 0) {
+            i++;
+            if (i < argc)
+                timeoutWithNoClients = atoi(argv[i]);
+            else {
+                UseMsg();
+                exit(1);
+            }
+        }
 #endif /* STARTSERVER */
 #ifndef AMOEBA
-	else if (strcmp(argv[i], "-pn") == 0)
-	    PartialNetwork = TRUE;
-	else if (strcmp(argv[i], "-nopn") == 0)
-	    PartialNetwork = FALSE;
+        else if (strcmp(argv[i], "-pn") == 0)
+            PartialNetwork = TRUE;
+        else if (strcmp(argv[i], "-nopn") == 0)
+            PartialNetwork = FALSE;
 #endif
-	else if (strcmp(argv[i], "-v") == 0)
-	  {
-	    NasConfig.DoVerbose = TRUE;
-	  }
-	else if (strcmp(argv[i], "-d") == 0)
-	  {
-	    i++;
-	    if (i < argc)
-	      NasConfig.DoDebug = atoi(argv[i]);
-	    else {
-	      UseMsg();
-	      exit(1);
-	    }
-	  }
-	else 
-	  {
-				/* see if the dda understands it.
-				   we pass (in addition to argc/argv
-				    an index to the current arg
-				    being processed.  If the arg is
-				    processed, i is set to the last arg
-				    processed (in the event of an option
-				    that takes an arguement */
-	    if (ddaProcessArg(&i, argc, argv))
-	      {			/* returns non-zero for an unidentified
-				   arg */
-		UseMsg();	/* this will call ddaUseMsg() */
-		exit(1);
-	      }
-	  }
-     }
+        else if (strcmp(argv[i], "-v") == 0) {
+            NasConfig.DoVerbose = TRUE;
+        } else if (strcmp(argv[i], "-config") == 0) {
+            i++;
+            if (i < argc)
+                i++;
+            else {
+                UseMsg();
+                exit(1);
+            }
+        } else if (strcmp(argv[i], "-b") == 0) {
+            NasConfig.DoDaemon = TRUE;
+        } else if (strcmp(argv[i], "-V") == 0) {        /* print version and exit */
+            printf("%s\n", release);
+            exit(0);
+        } else if (strcmp(argv[i], "-d") == 0) {
+            i++;
+            if (i < argc)
+                NasConfig.DoDebug = atoi(argv[i]);
+            else {
+                UseMsg();
+                exit(1);
+            }
+        } else if (strcmp(argv[i], "-local") == 0) {
+            NasConfig.LocalOnly = TRUE;
+        } else {
+            /* see if the dda understands it.
+               we pass (in addition to argc/argv
+               an index to the current arg
+               being processed.  If the arg is
+               processed, i is set to the last arg
+               processed (in the event of an option
+               that takes an arguement */
+            if (ddaProcessArg(&i, argc, argv)) {        /* returns non-zero for an unidentified
+                                                           arg */
+                UseMsg();       /* this will call ddaUseMsg() */
+                exit(1);
+            }
+        }
+    }
 }
 
 /* XALLOC -- X's internal memory allocator.  Why does it return unsigned
@@ -371,42 +373,39 @@ char	*argv[];
  * expectations of malloc, but this makes lint happier.
  */
 
-unsigned long * 
-Xalloc (amount)
-    unsigned long amount;
+void *
+Xalloc(unsigned long amount)
 {
-    char		*malloc();
-    register pointer  ptr;
-	
-    if ((long)amount <= 0)
-	return (unsigned long *)NULL;
+    register pointer ptr;
+
+    if ((long) amount <= 0)
+        return NULL;
     /* aligned extra on long word boundary */
     amount = (amount + 3) & ~3;
 #ifdef MEMBUG
     if (!Must_have_memory && Memory_fail &&
-	((random() % MEM_FAIL_SCALE) < Memory_fail))
-	return (unsigned long *)NULL;
+        ((random() % MEM_FAIL_SCALE) < Memory_fail))
+        return NULL;
 #endif
-    if (ptr = (pointer)malloc(amount))
-	return (unsigned long *)ptr;
+    if (ptr = (pointer) malloc(amount))
+        return ptr;
     if (Must_have_memory)
-	FatalError("Out of memory");
-    return (unsigned long *)NULL;
+        FatalError("Out of memory");
+    return NULL;
 }
 
 /*****************
  * Xcalloc
  *****************/
 
-unsigned long *
-Xcalloc (amount)
-    unsigned long   amount;
+void *
+Xcalloc(unsigned long amount)
 {
-    unsigned long   *ret;
+    unsigned long *ret;
 
-    ret = Xalloc (amount);
+    ret = Xalloc(amount);
     if (ret)
-	bzero ((char *) ret, (int) amount);
+        bzero((char *) ret, (int) amount);
     return ret;
 }
 
@@ -414,87 +413,78 @@ Xcalloc (amount)
  * Xrealloc
  *****************/
 
-unsigned long *
-Xrealloc (ptr, amount)
-    register pointer ptr;
-    unsigned long amount;
+void *
+Xrealloc(register pointer ptr, unsigned long amount)
 {
-    char *malloc();
-    char *realloc();
 
 #ifdef MEMBUG
     if (!Must_have_memory && Memory_fail &&
-	((random() % MEM_FAIL_SCALE) < Memory_fail))
-	return (unsigned long *)NULL;
+        ((random() % MEM_FAIL_SCALE) < Memory_fail))
+        return (unsigned long *) NULL;
 #endif
-    if ((long)amount <= 0)
-    {
-	if (ptr && !amount)
-	    free(ptr);
-	return (unsigned long *)NULL;
+    if (amount <= 0) {
+        if (ptr && !amount)
+            free(ptr);
+        return NULL;
     }
     amount = (amount + 3) & ~3;
     if (ptr)
-        ptr = (pointer)realloc((char *)ptr, amount);
+        ptr = (pointer) realloc((char *) ptr, amount);
     else
-	ptr = (pointer)malloc(amount);
+        ptr = (pointer) malloc(amount);
     if (ptr)
-        return (unsigned long *)ptr;
+        return ptr;
     if (Must_have_memory)
-	FatalError("Out of memory");
-    return (unsigned long *)NULL;
+        FatalError("Out of memory");
+    return NULL;
 }
-                    
+
 /*****************
  *  Xfree
  *    calls free 
- *****************/    
+ *****************/
 
 void
-Xfree(ptr)
-    register pointer ptr;
+Xfree(register pointer ptr)
 {
     if (ptr)
-	free((char *)ptr); 
+        free((char *) ptr);
 }
 
 #ifdef CAHILL_MALLOC
 #include <malloc.h>
 
-unsigned long * 
-debug_Xalloc (file, line, amount)
-    char *file;
-    int line;
-    unsigned long amount;
+void *
+debug_Xalloc(char *file, int line, unsigned long amount)
 {
-    register pointer  ptr;
-	
-    if ((long)amount <= 0)
-	return (unsigned long *)NULL;
+    register pointer ptr;
+
+    if ((long) amount <= 0)
+        return NULL;
     /* aligned extra on long word boundary */
     amount = (amount + 3) & ~3;
-    if (ptr = (pointer)debug_malloc(file, line, amount))
-	return (unsigned long *)ptr;
+    if (ptr = (pointer) debug_malloc(file, line, amount))
+        return ptr;
     if (Must_have_memory)
-	FatalError("Out of memory");
-    return (unsigned long *)NULL;
+        FatalError("Out of memory");
+    return NULL;
 }
 
 /*****************
  * Xcalloc
  *****************/
 
-unsigned long *
-debug_Xcalloc (file, line, amount)
-    char *file;
-    int line;
-    unsigned long   amount;
+void *
+debug_Xcalloc(char *file, int line, unsigned long amount)
+char *file;
+int line;
+unsigned long amount;
 {
-    unsigned long   *ret;
+    unsigned long *ret;
 
-    ret = debug_Xalloc (file, line, amount);
+    ret = debug_Xalloc(file, line, amount);
     if (ret)
-	bzero ((char *) ret, (int) amount);
+        bzero((char *) ret, (int) amount);
     return ret;
 }
 
@@ -502,66 +492,60 @@ debug_Xcalloc (file, line, amount)
  * Xrealloc
  *****************/
 
-unsigned long *
-debug_Xrealloc (file, line, ptr, amount)
-    char *file;
-    int line;
-    register pointer ptr;
-    unsigned long amount;
+void *
+debug_Xrealloc(char *file, int line, register pointer ptr,
+               unsigned long amount)
 {
-    if ((long)amount <= 0)
-    {
-	if (ptr && !amount)
-	    debug_free(file, line, ptr);
-	return (unsigned long *)NULL;
+    if ((long) amount <= 0) {
+        if (ptr && !amount)
+            debug_free(file, line, ptr);
+        return NULL;
     }
     amount = (amount + 3) & ~3;
     if (ptr)
-        ptr = (pointer)debug_realloc(file, line, (char *)ptr, amount);
+        ptr = (pointer) debug_realloc(file, line, (char *) ptr, amount);
     else
-	ptr = (pointer)debug_malloc(file, line, amount);
+        ptr = (pointer) debug_malloc(file, line, amount);
     if (ptr)
-        return (unsigned long *)ptr;
+        return ptr;
     if (Must_have_memory)
-	FatalError("Out of memory");
-    return (unsigned long *)NULL;
+        FatalError("Out of memory");
+    return NULL;
 }
-                    
+
 /*****************
  *  Xfree
  *    calls free 
- *****************/    
+ *****************/
 
 void
-debug_Xfree(file, line, ptr)
-    char *file;
-    int line;
-    register pointer ptr;
+debug_Xfree(char *file, int line, register pointer ptr)
 {
     if (ptr)
-	debug_free(file, line, (char *)ptr); 
+        debug_free(file, line, (char *) ptr);
 }
 #endif
 
-OsInitAllocator ()
+void
+OsInitAllocator(void)
 {
 #ifdef MEMBUG
-    static int	been_here;
+    static int been_here;
 
     /* Check the memory system after each generation */
     if (been_here)
-	CheckMemory ();
+        CheckMemory();
     else
-	been_here = 1;
+        been_here = 1;
 #endif
+    return;
 }
 
 /*VARARGS1*/
 void
-AuditF(f, s0, s1, s2, s3, s4, s5, s6, s7, s8, s9) /* limit of ten args */
-    char *f;
-    char *s0, *s1, *s2, *s3, *s4, *s5, *s6, *s7, *s8, *s9;
-{
+AuditF(char *f, char *s0, char *s1, char *s2, char *s3, char *s4, char *s5,
+       char *s6, char *s7, char *s8, char *s9)
+{                               /* limit of ten args */
 #ifdef X_NOT_STDC_ENV
     long tm;
 #else
@@ -569,65 +553,47 @@ AuditF(f, s0, s1, s2, s3, s4, s5, s6, s7, s8, s9) /* limit of ten args */
 #endif
     char *autime, *s;
 
-    if (*f != ' ')
-    {
-	time(&tm);
-	autime = ctime(&tm);
-	if (s = index(autime, '\n'))
-	    *s = '\0';
-	if (s = rindex(argvGlobal[0], '/'))
-	    s++;
-	else
-	    s = argvGlobal[0];
-	ErrorF("AUDIT: %s: %d %s: ", autime, getpid(), s);
+    if (*f != ' ') {
+        time(&tm);
+        autime = ctime(&tm);
+        if (s = index(autime, '\n'))
+            *s = '\0';
+        if (s = rindex(argvGlobal[0], '/'))
+            s++;
+        else
+            s = argvGlobal[0];
+        ErrorF("AUDIT: %s: %d %s: ", autime, getpid(), s);
     }
     ErrorF(f, s0, s1, s2, s3, s4, s5, s6, s7, s8, s9);
+
+    return;
 }
 
 /*VARARGS1*/
 void
-FatalError(f, s0, s1, s2, s3, s4, s5, s6, s7, s8, s9) /* limit of ten args */
-    char *f;
-    char *s0, *s1, *s2, *s3, *s4, *s5, *s6, *s7, *s8, *s9;
-{
+FatalError(char *f, char *s0, char *s1, char *s2, char *s3, char *s4,
+           char *s5, char *s6, char *s7, char *s8, char *s9)
+{                               /* limit of ten args */
     ErrorF("\nFatal server error:\n");
     ErrorF(f, s0, s1, s2, s3, s4, s5, s6, s7, s8, s9);
     ErrorF("\n");
     AbortServer();
-    /*NOTREACHED*/
+     /*NOTREACHED*/ return;
 }
 
 /*VARARGS1*/
 void
-ErrorF( f, s0, s1, s2, s3, s4, s5, s6, s7, s8, s9) /* limit of ten args */
-    char *f;
-    char *s0, *s1, *s2, *s3, *s4, *s5, *s6, *s7, *s8, *s9;
-{
-#ifdef AIXV3
-    fprintf(aixfd, f, s0, s1, s2, s3, s4, s5, s6, s7, s8, s9);
-    fflush (aixfd);
-
-    if (SyncOn)
-        sync();
-#else
+ErrorF(char *f, char *s0, char *s1, char *s2, char *s3, char *s4, char *s5,
+       char *s6, char *s7, char *s8, char *s9)
+{                               /* limit of ten args */
 #ifdef AMOEBA
     mu_lock(&print_lock);
 #endif
-    fprintf( stderr, f, s0, s1, s2, s3, s4, s5, s6, s7, s8, s9);
+    fprintf(stderr, f, s0, s1, s2, s3, s4, s5, s6, s7, s8, s9);
 #ifdef AMOEBA
     mu_unlock(&print_lock);
 #endif
-#endif
+
+    return;
 }
 
-#ifdef AIXV3
-OpenDebug()
-{
-        if((aixfd = fopen(AIXFILE,"w")) == NULL )
-        {
-                fprintf(stderr,"open aixfile failed\n");
-                exit(-1);
-        }
-        chmod(AIXFILE,00777);
-}
-#endif
